#!/bin/ksh
# set -x

Usage()
{
    echo "agentcfg -a <agent> <-u|-i>"
    echo "   agent_name : Name of the agent."
    echo "   -i         : install."
    echo "   -u         : uninstall."
    exit 1
}

#PAL_VERSION=33
PAL_VERSION=33
REGCTL=$PKG_INSTALL_ROOT/opt/VRTSobc/pal${PAL_VERSION}/bin/vxregctl
REGFILE=$PKG_INSTALL_ROOT/etc/vx/isis/Registry
VEACONFIG=$PKG_INSTALL_ROOT/opt/VRTSobc/pal${PAL_VERSION}/bin/veaconfig
VXSVC=$PKG_INSTALL_ROOT/opt/VRTSob/bin/vxsvc
uninstall=2
debug=0
while getopts :a:u: name
do
    case $name in
        a) agent=$OPTARG;;
        u) uninstall=1
        i) uninstall=0
        d) debug=1
    esac
done


if [ "$agent" = "" ];
then
  Usage
fi
if [ $uninstall = 2 ];
then
    echo Invalid invocation.   
    Usage
fi   
# if mode is standalone set the agent info to stand alone and leave
mode=`$REGCTL $REGFILE queryvalue  Software/VERITAS/VRTSobc/pal${PAL_VERSION}/Agents/__defaults Mode`
if [ $? != 0 ]
then
   echo Default mode entry missing in registry 
   exit 1
fi

mode=`echo $mode |sed -e 's/^.*: //g'`
LH=`/opt/VRTSobc/pal33/bin/vxregctl /etc/vx/isis/Registry queryvalue  Software/VERITAS/VRTSobc/pal33/Agents/__defaults/Network/Params/Security LocalSystem`
if [ $? != 0 ]
then
   echo LocalSystem entry is missing in the registry 
   exit 1
fi
LH=`echo $LH |sed -e 's/^.*: //g'`

# if running in HC mode no uninstall required. During install reset the security setting for agent
if [ $mode = 1 ];
then
   if [ $uninstall = 1 ];
   then
       exit 0
   else
       $VEACONFIG -c setagentinfo -a $agent -m standalone
       exit 0
   fi
fi


# Agent is set in domain controller mode. Join local vxsvc and central server

# See if VRTSob is installed in local host. If so make sure it is running .

obVersion=`$REGCTL $REGFILE queryvalue  Software/VERITAS/VxSvc/CurrentVersion/ VERSION`

if [ $? != 0 ];
then
   echo Unable to determine the vxsvc version 
   exit 1
fi
obVersion=`echo $obVersion |grep 3.3'`
if [ "$obVersion" != "" ]; 
then
  $VXSVC -m > /var/vx/isis/svrstatus
  grep "NOT RUNNING" /var/vx/isis/svrstatus
  if [ $? = 0 ];
  then
        echo Please start VxSvc on the local host and run the command
        rm /var/vx/isis/svrstatus
        exit 1
  else
      rm /var/vx/isis/svrstatus
  fi
else
  echo INFO: Older version of vxsvc found(OK) >> /var/vx/isis/cfg_error.log
fi
#  Find the domain controller and broker host

DC=`/opt/VRTSobc/pal33/bin/vxini -f /etc/default/csf_resolv.conf -s DOMAIN_CONTROLLER -k domain -q`
if [ $? != 0 ];
then
    echo Domain controller entry missing in csf_resolv.conf  >> /var/vx/isis/cfg_error.log
    if [$uninstall != 1]
    then
         exit 5
    fi
fi

AB=`/opt/VRTSobc/pal33/bin/vxini -f /etc/default/csf_resolv.conf -s SECURITY -k BROKER_HOST -q`
if [ $? != 0 ]
then
    echo broker host missing in csf_resolv.conf >> /var/vx/isis/cfg_error.log
    exit 2
fi

agent_id=$AB:vea_agent@vea_domain.vx
if [ $uninstall!=1 ];
then 
  $VEACONFIG -c setagentinfo  -a $agent -n $agent_id -m Domain 
  # During install join the central server and local server. During uninstall leave the domain.

  $VEACONFIG -c joindc -l $DC  -u  $agent_id -a $agent@$LH 
  rc=$?
  if [ $rc != 0 ];
  then
     exit $rc
  fi
  $VEACONFIG -c joindc -l $LH  -u  $agent_id -a $agent@$LH
  rc=$?
  if [ $rc != 0 ];
  then
     exit $rc
  fi
else
    $VEACONFIG -c leavedc -l $DC  -u  $agent_id -a $agent@$LH --no-prompt
    rc=$?
    if [ $rc != 0 ];
    then
       exit $rc
    fi
    $VEACONFIG -c leavedc -l $LH  -u  $agent_id -a $agent@$LH --no-prompt
    rc=$?
    if [ $rc != 0];
    then
        exit $rc
    fi
fi

exit 0
