#!/bin/ksh


VXREGCTL=/opt/VRTSob/bin/vxregctl
REGISTRY=/etc/vx/isis/Registry
VXPALCTRL=/opt/VRTSobc/pal33/bin/vxpalctrl
VXSVCCTRL=/opt/VRTSob/bin/vxsvcctrl
OSUUID=/etc/vx/uuid/bin/osuuid
CSFRESOLV=/etc/default/csf_resolv.conf
CFGSECURITY=/opt/VRTSobc/pal33/install/cfgsecurity.sh

while getopts :p: name
do
    case $name in
        p) PASS=$OPTARG;;
    esac
done

if  [ -z "$PASS" ] &&  [ $# -gt 0 ]  
then
        echo "Usage:"
        echo "       vea_config_clone.sh [-p password]"
        echo "       If password is not provided user will be prompted for it."
        exit -9
fi  


#Routine to stop vxsvc along with all agents
stop_all()
{
    #Stopping all agents
    for i in $AGENT_LIST
    do
        $VXPALCTRL -a $i -c stop 2>&1
    done

    #Stopping vxsvc
    $VXSVCCTRL stop 2>&1

}

#Routine to  regenerate hostguid and persistent id for agents
regenerate()
{
    #Generating new Hostguid
    $OSUUID create --reset 1>/dev/null
    if [ $? != 0 ]
    then
        echo "Error in recreating hostguid" >&2
        exit -2
    fi

    #Deleting Persistentid for vxsvc
    $VXREGCTL $REGISTRY deletevalue Software/VERITAS/VxSvc/CurrentVersion PERSISTENT_ID 2>&1

    #Deleting Persistentid for all agents
    for i in $AGENT_LIST
    do
        $VXREGCTL $REGISTRY deletevalue Software/VERITAS/VRTSobc/pal33/Agents/$i PERSISTENT_ID 2>&1
    done

    #Runnning cfgsecurity for vxsvc
    local DC=`grep  'domain =' $CSFRESOLV | cut -f 2 -d '"'`
    local AB=`grep BROKER_HOST $CSFRESOLV | cut -f 2 -d '"'`
    if [ -z "$PASS" ]
    then
        echo "Please enter the agent password:"
        stty -echo
        read PASS
        stty echo
    fi
    $CFGSECURITY -a root -h `hostname` -d $DC -p $PASS -b $AB 2>&1
    if [ $? != 0 ]
    then
        echo "Error running cfgsecurity for root agent" >&2
        exit -3 
    fi

    #Runnning cfgsecurity for all agents
    for i in $AGENT_LIST
    do
        $CFGSECURITY -a $i -h `hostname` -d $DC -p $PASS -b $AB 2>&1
        if [ $? != 0 ]
        then
            echo "Error running cfgsecurity for agent $i" >&2
            exit -4 
        fi
    done
}

#Routine to start vxsvc and agents
start_all()
{
    #Starting vxsvc
    $VXSVCCTRL start 2>&1
    if [ $? != 0 ]
    then
        echo "Error starting vxsvc" >&2
        exit -5 
    fi

    #Starting all agents
    for i in $AGENT_LIST
    do
        $VXPALCTRL -a $i -c start 2>&1
        if [ $? != 0 ]
        then
            echo "Error starting agent $i" >&2
            exit -6 
        fi
    done
}

#main
main()
{
    #Obtaining list of agents from registry
    AGENT_LIST=`$VXREGCTL $REGISTRY enumkey Software/VERITAS/VRTSobc/pal33/Agents |grep -v __defaults`
    if [ $? != 0 ]
    then
        echo "Error reading agent names from Registry" >&2
        exit -1
    fi

    stop_all
    regenerate
    start_all

    exit 0
}

main
